
#ifndef _C16_co754_
#define _C16_co754_

#ifdef __cplusplus
extern "C" {
#endif

extern void F313_4202(EIF_REFERENCE, EIF_CHARACTER_8);
extern void EIF_Minit754(void);
extern char *(*R4032[])();
extern char *(*R3898[])();

#ifdef __cplusplus
}
#endif

#endif
